@@ -4,22 +4,16 @@
 ( cd opt/kde/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so.0 )
 ( cd opt/kde/lib ; rm -rf libartsmodulescommon.so )
 ( cd opt/kde/lib ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so )
-( cd opt/kde/lib ; rm -rf libakode.so.1 )
-( cd opt/kde/lib ; ln -sf libakode.so.1.0.0 libakode.so.1 )
 ( cd opt/kde/lib ; rm -rf libartsmidi_idl.so )
 ( cd opt/kde/lib ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so )
 ( cd opt/kde/lib ; rm -rf libartsmidi.so )
 ( cd opt/kde/lib ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so )
 ( cd opt/kde/lib ; rm -rf libnoatun.so )
 ( cd opt/kde/lib ; ln -sf libnoatun.so.1.2.0 libnoatun.so )
-( cd opt/kde/lib ; rm -rf libyafcore.so )
-( cd opt/kde/lib ; ln -sf libyafcore.so.0.0.0 libyafcore.so )
 ( cd opt/kde/lib ; rm -rf libmpeg.so )
 ( cd opt/kde/lib ; ln -sf libmpeg-0.3.0.so libmpeg.so )
 ( cd opt/kde/lib ; rm -rf libartscontrolsupport.so )
 ( cd opt/kde/lib ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so )
-( cd opt/kde/lib ; rm -rf libyafxplayer.so.0 )
-( cd opt/kde/lib ; ln -sf libyafxplayer.so.0.0.0 libyafxplayer.so.0 )
 ( cd opt/kde/lib ; rm -rf libnoatuncontrols.so )
 ( cd opt/kde/lib ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so )
 ( cd opt/kde/lib ; rm -rf libartsmidi_idl.so.0 )
@@ -44,12 +38,8 @@
 ( cd opt/kde/lib ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so.1 )
 ( cd opt/kde/lib ; rm -rf libkmidlib.so.0 )
 ( cd opt/kde/lib ; ln -sf libkmidlib.so.0.0.0 libkmidlib.so.0 )
-( cd opt/kde/lib ; rm -rf libyafcore.so.0 )
-( cd opt/kde/lib ; ln -sf libyafcore.so.0.0.0 libyafcore.so.0 )
 ( cd opt/kde/lib ; rm -rf libartscontrolapplet.so )
 ( cd opt/kde/lib ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so )
-( cd opt/kde/lib ; rm -rf libakode.so )
-( cd opt/kde/lib ; ln -sf libakode.so.1.0.0 libakode.so )
 ( cd opt/kde/lib ; rm -rf libartsmoduleseffects.so.0 )
 ( cd opt/kde/lib ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so.0 )
 ( cd opt/kde/lib ; rm -rf libartsmodules.so.0 )
@@ -72,8 +62,8 @@
 ( cd opt/kde/lib ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so.0 )
 ( cd opt/kde/lib ; rm -rf libaudiocdplugins.so.1 )
 ( cd opt/kde/lib ; ln -sf libaudiocdplugins.so.1.0.0 libaudiocdplugins.so.1 )
-( cd opt/kde/lib ; rm -rf libyafxplayer.so )
-( cd opt/kde/lib ; ln -sf libyafxplayer.so.0.0.0 libyafxplayer.so )
+( cd opt/kde/lib ; rm -rf libarts_xine.so )
+( cd opt/kde/lib ; ln -sf libarts_xine.so.0.0.0 libarts_xine.so )
 ( cd opt/kde/lib ; rm -rf libarts_splay.so.0 )
 ( cd opt/kde/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so.0 )
 ( cd opt/kde/lib ; rm -rf libartsmidi.so.0 )
@@ -84,6 +74,8 @@
 ( cd opt/kde/lib ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so )
 ( cd opt/kde/lib ; rm -rf libarts_mpeglib.so )
 ( cd opt/kde/lib ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib.so )
+( cd opt/kde/lib ; rm -rf libarts_audiofile.so )
+( cd opt/kde/lib ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so )
 ( cd opt/kde/lib ; rm -rf libnoatun.so.1 )
 ( cd opt/kde/lib ; ln -sf libnoatun.so.1.2.0 libnoatun.so.1 )
 ( cd opt/kde/lib ; rm -rf libaudiocdplugins.so )
@@ -94,8 +86,12 @@
 ( cd opt/kde/lib ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so )
 ( cd opt/kde/lib ; rm -rf libartsmoduleseffects.so )
 ( cd opt/kde/lib ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so )
+( cd opt/kde/lib ; rm -rf libarts_audiofile.so.0 )
+( cd opt/kde/lib ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so.0 )
 ( cd opt/kde/lib ; rm -rf libartsmodulessynth.so )
 ( cd opt/kde/lib ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so )
+( cd opt/kde/lib ; rm -rf libarts_xine.so.0 )
+( cd opt/kde/lib ; ln -sf libarts_xine.so.0.0.0 libarts_xine.so.0 )
 ( cd opt/kde/share/doc/HTML/en/juk ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/juk ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kmid ; rm -rf common )
@@ -108,9 +104,9 @@
 ( cd opt/kde/share/doc/HTML/en/kscd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kaboodle ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kaboodle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/artsbuilder ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kaudiocreator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kaudiocreator ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/noatun ; ln -sf /opt/kde/share/doc/HTML/en/common common )
